==> xmonad-0.13-12-armv7h.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-A7zQG8GX950IBxTTEvNCxr
key: xmonad-0.13-A7zQG8GX950IBxTTEvNCxr
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
indefinite: False
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 1e07bbd19daef0d191effd0c433df07f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.13-A7zQG8GX950IBxTTEvNCxr
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    filepath-1.4.1.2 setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0 unix-2.7.2.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp=c2d7d8b52a62dd5cd8e4c2fd40180167
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             X11-1.8-JnAOOA5ca1mBqz6w5LwuYT=d42095e6df3db8f22e7846b4fbf85785
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.13-13-armv7h.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-K842KXy8eLK2djQHd55ZyZ
key: xmonad-0.13-K842KXy8eLK2djQHd55ZyZ
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
indefinite: False
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 6087f83c7d56ca0a296759d7d42b2125
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.13-K842KXy8eLK2djQHd55ZyZ
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    filepath-1.4.1.2 setlocale-1.0.0.6-FNDcuV77y1s8AJnuWYvxkt
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc process-1.6.1.0 unix-2.7.2.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             setlocale-1.0.0.6-FNDcuV77y1s8AJnuWYvxkt=26f6ae7b91aec994c081383d7ec1633e
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             X11-1.8-JnAOOA5ca1mBqz6w5LwuYT=d42095e6df3db8f22e7846b4fbf85785
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
